==> gnome-shell-44.3.tar.xz: gnome-shell-44.3/.gitlab/issue_templates/Bug.md <==
<!-- 
Please read https://wiki.gnome.org/Community/GettingInTouch/BugReportingGuidelines
first to ensure that you create a clear and specific issue.
-->

### Affected version

<!--
Provide at least the following information:
* Your OS and version
* Affected GNOME Shell version (see https://wiki.gnome.org/Schedule for currently supported versions)
* Does this issue appear in XOrg and/or Wayland
* Does this issue happen without extensions (please follow instructions below)

To properly disable extensions you can use gnome-extensions-app and then restart
your session. Disabling extensions without a restart is not sufficient to rule
out extensions as cause of a bug. If an issue can only be reproduced with a
certain extension, please file a bug report against that extension first.
-->

### Bug summary

<!-- 
Provide a short summary of the bug you encountered.
-->

### Steps to reproduce

<!-- 
1. Step one
2. Step two
3. ...
-->

### What happened

<!-- 
What did GNOME Shell do that was unexpected?
-->

### What did you expect to happen

<!-- 
What did you expect GNOME Shell to do?
-->

### Relevant logs, screenshots, screencasts etc.

<!-- 
If you have further information, such as technical documentation, logs,
screenshots or screencasts related, please provide them here.

If the bug is a crash, please obtain a stack trace with installed debug
symbols (at least for GNOME Shell and Mutter) and attach it to
this issue following the instructions on
https://wiki.gnome.org/Community/GettingInTouch/Bugzilla/GettingTraces.
-->


<!-- Do not remove the following line. -->
/label ~"1. Bug"

==> gnome-shell_49.0.orig.tar.xz: gnome-shell-49.0/.gitlab/issue_templates/Bug.md <==
<!--
Please read https://gitlab.gnome.org/GNOME/gnome-shell/-/tree/main#reporting-bugs
first to ensure that you create a clear and specific issue.
-->

### Affected version

<!--
Provide at least the following information:
* Your OS and version
* Affected GNOME Shell version (see https://release.gnome.org/calendar/
  for currently supported versions)
* Does this issue appear in XOrg and/or Wayland
* Does this issue happen without extensions (please follow instructions below)

To properly disable extensions you can use gnome-extensions-app and then restart
your session. Disabling extensions without a restart is not sufficient to rule
out extensions as cause of a bug. If an issue can only be reproduced with a
certain extension, please file a bug report against that extension first.
-->

### Bug summary

<!-- 
Provide a short summary of the bug you encountered.
-->

### Steps to reproduce

<!-- 
1. Step one
2. Step two
3. ...
-->

### What happened

<!-- 
What did GNOME Shell do that was unexpected?
-->

### What did you expect to happen

<!-- 
What did you expect GNOME Shell to do?
-->

### Relevant logs, screenshots, screencasts etc.

<!-- 
If you have further information, such as technical documentation, logs,
screenshots or screencasts related, please provide them here.

If the bug is a crash, please obtain a stack trace with installed debug
symbols (at least for GNOME Shell and Mutter) and attach it to
this issue following the instructions on
https://handbook.gnome.org/issues/stack-traces.html.
-->


<!-- Do not remove the following line. -->
/label ~"1. Bug"
